==> Gambio v4.1.1.2.zip: Vollversion GX v4.1.1.2/Shopsystem/Dateien/lang/german/original_sections/modules/payment/amazon.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	amazon.lang.inc.php 2015-01-02 gm
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2015 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = array
(
	'MODULE_PAYMENT_AMAZON_ALLOWED_DESC' => 'Geben Sie <b>einzeln</b> die Zonen an, welche für dieses Modul erlaubt sein sollen. (z.B. AT,DE (wenn leer, werden alle Zonen erlaubt))',
	'MODULE_PAYMENT_AMAZON_ALLOWED_TITLE' => 'Erlaubte Zonen',
	'MODULE_PAYMENT_AMAZON_ORDER_STATUS_ID_DESC' => 'Bestellungen, welche mit diesem Modul gemacht werden, auf diesen Status setzen',
	'MODULE_PAYMENT_AMAZON_ORDER_STATUS_ID_TITLE' => 'Bestellstatus festlegen',
	'MODULE_PAYMENT_AMAZON_SORT_ORDER_DESC' => 'Reihenfolge der Anzeige. Kleinste Ziffer wird zuerst angezeigt.',
	'MODULE_PAYMENT_AMAZON_SORT_ORDER_TITLE' => 'Anzeigereihenfolge',
	'MODULE_PAYMENT_AMAZON_STATUS_DESC' => 'Möchten Sie Zahlungen per Amazon akzeptieren?',
	'MODULE_PAYMENT_AMAZON_STATUS_TITLE' => 'Bezahlungen durch Amazon aktivieren',
	'MODULE_PAYMENT_AMAZON_TEXT_DESCRIPTION' => 'Zahlung via Amazon',
	'MODULE_PAYMENT_AMAZON_TEXT_INFO' => 'Zahlung via Amazon',
	'MODULE_PAYMENT_AMAZON_TEXT_TITLE' => 'Zahlung via Amazon',
	'MODULE_PAYMENT_AMAZON_ZONE_DESC' => 'Wenn eine Zone ausgewählt ist, gilt die Zahlungsmethode nur für diese Zone.',
	'MODULE_PAYMENT_AMAZON_ZONE_TITLE' => 'Zahlungszone'
);

==> Gambio v5.0.2.0.zip: Vollversion GX v5.0.2.0/Shopsystem/Dateien/lang/german/original_sections/modules/payment/amazon.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	amazon.lang.inc.php 2015-01-02 gm
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2015 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = array
(
	'MODULE_PAYMENT_AMAZON_ALLOWED_DESC' => 'Gib <b>einzeln</b> die Zonen an, welche für dieses Modul erlaubt sein sollen. (z.B. AT,DE (wenn leer, werden alle Zonen erlaubt))',
	'MODULE_PAYMENT_AMAZON_ALLOWED_TITLE' => 'Erlaubte Zonen',
	'MODULE_PAYMENT_AMAZON_ORDER_STATUS_ID_DESC' => 'Bestellungen, welche mit diesem Modul gemacht werden, auf diesen Status setzen',
	'MODULE_PAYMENT_AMAZON_ORDER_STATUS_ID_TITLE' => 'Bestellstatus festlegen',
	'MODULE_PAYMENT_AMAZON_SORT_ORDER_DESC' => 'Reihenfolge der Anzeige. Kleinste Ziffer wird zuerst angezeigt.',
	'MODULE_PAYMENT_AMAZON_SORT_ORDER_TITLE' => 'Anzeigereihenfolge',
	'MODULE_PAYMENT_AMAZON_STATUS_DESC' => 'Möchtest du Zahlungen per Amazon akzeptieren?',
	'MODULE_PAYMENT_AMAZON_STATUS_TITLE' => 'Bezahlungen durch Amazon aktivieren',
	'MODULE_PAYMENT_AMAZON_TEXT_DESCRIPTION' => 'Zahlung via Amazon',
	'MODULE_PAYMENT_AMAZON_TEXT_INFO' => 'Zahlung via Amazon',
	'MODULE_PAYMENT_AMAZON_TEXT_TITLE' => 'Zahlung via Amazon',
	'MODULE_PAYMENT_AMAZON_ZONE_DESC' => 'Wenn eine Zone ausgewählt ist, gilt die Zahlungsmethode nur für diese Zone.',
	'MODULE_PAYMENT_AMAZON_ZONE_TITLE' => 'Zahlungszone'
);
